@@ -37,7 +37,7 @@
 #include "gsttracerfactory.h"
 #include "gsttracerutils.h"
 
-#ifndef GST_DISABLE_GST_DEBUG
+#ifndef GST_DISABLE_GST_TRACER_HOOKS
 
 /* tracer quarks */
 
@@ -66,7 +66,7 @@ GHashTable *_priv_tracers = NULL;
 void
 _priv_gst_tracing_init (void)
 {
-  const gchar *env = g_getenv ("GST_TRACER_PLUGINS");
+  const gchar *env = g_getenv ("GST_TRACERS");
 
   if (env != NULL && *env != '\0') {
     GstRegistry *registry = gst_registry_get ();
@@ -151,15 +151,7 @@ _priv_gst_tracing_deinit (void)
   _priv_tracers = NULL;
 }
 
-/**
- * gst_tracing_register_hook_id:
- * @tracer: the tracer
- * @detail: the detailed hook
- * @func: (scope async): the callback
- *
- * Register @func to be called when the trace hook @detail is getting invoked.
- */
-void
+static void
 gst_tracing_register_hook_id (GstTracer * tracer, GQuark detail, GCallback func)
 {
   gpointer key = GINT_TO_POINTER (detail);
@@ -182,6 +174,7 @@ gst_tracing_register_hook_id (GstTracer * tracer, GQuark detail, GCallback func)
  * @func: (scope async): the callback
  *
  * Register @func to be called when the trace hook @detail is getting invoked.
+ * Use %NULL for @detail to register to all hooks.
  */
 void
 gst_tracing_register_hook (GstTracer * tracer, const gchar * detail,
@@ -190,4 +183,4 @@ gst_tracing_register_hook (GstTracer * tracer, const gchar * detail,
   gst_tracing_register_hook_id (tracer, g_quark_try_string (detail), func);
 }
 
-#endif /* GST_DISABLE_GST_DEBUG */
+#endif /* GST_DISABLE_GST_TRACER_HOOKS */
